@@ -12,20 +12,19 @@
 
 label="grib_get_fail_test"
 tempText=temp.$label.txt
-REDIRECT=/dev/null
 
 # Check input file has been downloaded
 [ -f ${data_dir}/regular_latlon_surface.grib1 ]
 
 # Expect failure as the key does not exist
 set +e
-${tools_dir}/grib_get -p boomerang ${data_dir}/regular_latlon_surface.grib1 2> $REDIRECT > $REDIRECT
-if [ $? -eq 0 ] ; then
-  exit 1;  # Should not have succeeded
-fi
+${tools_dir}/grib_get -p boomerang ${data_dir}/regular_latlon_surface.grib1
+status=$?
 set -e
+[ $status -ne 0 ]
 
 # ECC-1551: Print which key does not exist
+# -----------------------------------------
 set +e
 ${tools_dir}/grib_get -p Ni,Nh,Nj $ECCODES_SAMPLES_PATH/GRIB2.tmpl > $tempText 2>&1
 status=$?
@@ -33,4 +32,5 @@ set -e
 [ $status -ne 0 ]
 grep -q "Nh (Key/value not found)" $tempText
 
+# Clean up
 rm -f $tempText
