@@ -118,7 +118,7 @@ static void new_keys_list()
     grib_context* c = grib_context_get_default();
     keys_list       = (grib_string_list*)grib_context_malloc_clear(c, sizeof(grib_string_list));
     if (!keys_list) {
-        fprintf(stderr, "Failed to allocate memory for keys list");
+        fprintf(stderr, "%s: Failed to allocate memory for keys list", tool_name);
         exit(1);
     }
 }
@@ -238,8 +238,6 @@ int grib_tool_before_getopt(grib_runtime_options* options)
 int grib_tool_init(grib_runtime_options* options)
 {
     int ret               = 0, i;
-    int nfiles            = 1;
-    char orderby[]        = "md5Headers";
     grib_context* context = grib_context_get_default();
 
     options->strict = 1;
@@ -281,11 +279,11 @@ int grib_tool_init(grib_runtime_options* options)
         headerMode = 0;
 
     if (grib_options_on("H") && grib_options_on("c:")) {
-        fprintf(stderr, "Error: -H and -c options are incompatible. Choose one of the two please.\n");
+        fprintf(stderr, "%s: -H and -c options are incompatible. Choose one of the two please.\n",tool_name);
         exit(1);
     }
     if (grib_options_on("a") && !grib_options_on("c:")) {
-        fprintf(stderr, "Error: -a option requires -c option. Please define a list of keys with the -c option.\n");
+        fprintf(stderr, "%s: -a option requires -c option. Please define a list of keys with the -c option.\n",tool_name);
         exit(1);
     }
 
@@ -306,27 +304,12 @@ int grib_tool_init(grib_runtime_options* options)
     /* Check 1st file is not a directory */
     exit_if_input_is_directory(tool_name, options->infile_extra->name);
 
-    if (grib_options_on("r")) {
-        const char* filename[1];
-        filename[0]      = options->infile_extra->name;
-        options->random  = 1;
-        options->orderby = strdup(orderby);
-        options->idx     = grib_fieldset_new_from_files(context, filename,
-                                                    nfiles, 0, 0, 0, orderby, &ret);
-        if (ret) {
-            fprintf(stderr, "unable to create index for input file %s (%s)",
-                    options->infile_extra->name, grib_get_error_message(ret));
-            exit(ret);
-        }
-    }
-    else {
-        options->random             = 0;
-        options->infile_extra->file = fopen(options->infile_extra->name, "r");
+    options->random             = 0;
+    options->infile_extra->file = fopen(options->infile_extra->name, "r");
 
-        if (!options->infile_extra->file) {
-            perror(options->infile_extra->name);
-            exit(1);
-        }
+    if (!options->infile_extra->file) {
+        perror(options->infile_extra->name);
+        exit(1);
     }
 
     global_tolerance = 0;
@@ -475,6 +458,7 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
 
         if (compare_handles(h, global_handle, options)) {
             error++;
+            write_messages(h, global_handle);
             if (!force)
                 exit(1);
         }
@@ -483,10 +467,9 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
 
         return 0;
     }
-    else if (options->random)
-        global_handle = grib_fieldset_next_handle(options->idx, &err);
-    else
+    else {
         global_handle = bufr_handle_new_from_file_x(h->context, options->infile_extra->file, options->mode, 0, &err);
+    }
 
     if (!global_handle || err != GRIB_SUCCESS) {
         morein2++;
@@ -497,6 +480,7 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
 
     if (compare_handles(global_handle, h, options)) {
         error++;
+        write_messages(global_handle, h);
         if (!two_way) {
             /* If two_way mode: Don't exit yet. Show further differences */
             if (!force)
@@ -510,6 +494,7 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
             printf("  Swapping handles (two-way mode)\n");
         if (compare_handles(h, global_handle, options)) {
             error++;
+            write_messages(h, global_handle);
             if (!force)
                 exit(1);
         }
@@ -530,7 +515,7 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
 int grib_tool_skip_handle(grib_runtime_options* options, grib_handle* h)
 {
     int err = 0;
-    if (!options->through_index && !options->random) {
+    if (!options->through_index) {
         global_handle = codes_bufr_handle_new_from_file(h->context, options->infile_extra->file, &err);
 
         if (!global_handle || err != GRIB_SUCCESS)
@@ -1223,7 +1208,6 @@ static int compare_attributes(grib_handle* handle1, grib_handle* handle2, grib_r
 
         if (compare_attribute(handle1, handle2, options, aa, prefix, err)) {
             (*err)++;
-            write_messages(handle1, handle2);
             ret = 1;
         }
 
@@ -1243,7 +1227,6 @@ static int compare_attribute(grib_handle* handle1, grib_handle* handle2, grib_ru
     snprintf(fullname, fullnameMaxLen, "%s->%s", prefix, a->name);
     if (compare_values(options, handle1, handle2, fullname, GRIB_TYPE_UNDEFINED)) {
         (*err)++;
-        write_messages(handle1, handle2);
         ret = 1;
     }
     /* Recurse if this key has children */
@@ -1321,13 +1304,11 @@ static int compare_all_dump_keys(grib_handle* handle1, grib_handle* handle2, gri
         /* Compare the key itself */
         if (compare_values(options, handle1, handle2, prefix, GRIB_TYPE_UNDEFINED)) {
             (*pErr)++;
-            write_messages(handle1, handle2);
             ret = 1;
         }
         /* Now compare the key attributes (if any) */
         if (compare_attributes(handle1, handle2, options, xa, prefix, pErr)) {
             (*pErr)++;
-            write_messages(handle1, handle2);
             ret = 1;
         }
         if (dofree)
@@ -1346,23 +1327,11 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
     grib_keys_iterator* iter = NULL;
     const char* name         = NULL;
 
-    /* mask only if no -c option or headerMode (-H)*/
-    if (blocklist && (!listFromCommandLine || headerMode)) {
-        /* See ECC-245, GRIB-573, GRIB-915: Do not change handles in memory */
-        /*
-        grib_string_list* nextb=blocklist;
-        while (nextb) {
-            grib_clear(handle1,nextb->value);
-            grib_clear(handle2,nextb->value);
-            nextb=nextb->next;
-        }*/
-    }
-
     if (listFromCommandLine && onlyListed) {
         for (i = 0; i < options->compare_count; i++) {
             if (blocklisted(options->compare[i].name))
                 continue;
-            if (options->compare[i].type == GRIB_NAMESPACE) {
+            if (options->compare[i].type == CODES_NAMESPACE) {
                 iter = grib_keys_iterator_new(handle1, 0, options->compare[i].name);
                 if (!iter) {
                     grib_context_log(handle1->context, GRIB_LOG_ERROR, "unable to get iterator");
@@ -1376,7 +1345,6 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
                         continue;
                     if (compare_values(options, handle1, handle2, name, GRIB_TYPE_UNDEFINED)) {
                         err++;
-                        write_messages(handle1, handle2);
                     }
                 }
                 grib_keys_iterator_delete(iter);
@@ -1384,7 +1352,6 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
             else {
                 if (compare_values(options, handle1, handle2, options->compare[i].name, options->compare[i].type))
                     err++;
-                write_messages(handle1, handle2);
             }
         }
     }
@@ -1424,7 +1391,7 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
             for (i = 0; i < options->compare_count; i++) {
                 if (blocklisted(name))
                     continue;
-                if (options->compare[i].type == GRIB_NAMESPACE) {
+                if (options->compare[i].type == CODES_NAMESPACE) {
                     iter = grib_keys_iterator_new(handle1, 0, options->compare[i].name);
                     if (!iter) {
                         grib_context_log(handle1->context, GRIB_LOG_ERROR,
@@ -1439,7 +1406,6 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
                             continue;
                         if (compare_values(options, handle1, handle2, name, GRIB_TYPE_UNDEFINED)) {
                             err++;
-                            write_messages(handle1, handle2);
                             if (compare_all_dump_keys(handle1, handle2, options, &err)) {
                                 err++;
                             }
@@ -1450,7 +1416,6 @@ static int compare_handles(grib_handle* handle1, grib_handle* handle2, grib_runt
                 else {
                     if (compare_values(options, handle1, handle2, options->compare[i].name, options->compare[i].type)) {
                         err++;
-                        write_messages(handle1, handle2);
                         if (compare_all_dump_keys(handle1, handle2, options, &err)) {
                             err++;
                         }
